package com.yijia.integral.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yijia.integral.mapper.IntegralShopPicMapper;
import com.yijia.integral.domain.IntegralShopPic;
import com.yijia.integral.service.IIntegralShopPicService;

/**
 * 积分商城图片信息Service业务层处理
 * 
 * @author yijia
 * @date 2021-03-18
 */
@Service
public class IntegralShopPicServiceImpl implements IIntegralShopPicService 
{
    @Autowired
    private IntegralShopPicMapper integralShopPicMapper;

    /**
     * 查询积分商城图片信息
     * 
     * @param id 积分商城图片信息ID
     * @return 积分商城图片信息
     */
    @Override
    public IntegralShopPic selectIntegralShopPicById(Long id)
    {
        return integralShopPicMapper.selectIntegralShopPicById(id);
    }

    /**
     * 查询积分商城图片信息列表
     * 
     * @param integralShopPic 积分商城图片信息
     * @return 积分商城图片信息
     */
    @Override
    public List<IntegralShopPic> selectIntegralShopPicList(IntegralShopPic integralShopPic)
    {
        return integralShopPicMapper.selectIntegralShopPicList(integralShopPic);
    }

    /**
     * 新增积分商城图片信息
     * 
     * @param integralShopPic 积分商城图片信息
     * @return 结果
     */
    @Override
    public int insertIntegralShopPic(IntegralShopPic integralShopPic)
    {
        return integralShopPicMapper.insertIntegralShopPic(integralShopPic);
    }

    /**
     * 修改积分商城图片信息
     * 
     * @param integralShopPic 积分商城图片信息
     * @return 结果
     */
    @Override
    public int updateIntegralShopPic(IntegralShopPic integralShopPic)
    {
        return integralShopPicMapper.updateIntegralShopPic(integralShopPic);
    }

    /**
     * 批量删除积分商城图片信息
     * 
     * @param ids 需要删除的积分商城图片信息ID
     * @return 结果
     */
    @Override
    public int deleteIntegralShopPicByIds(Long[] ids)
    {
        return integralShopPicMapper.deleteIntegralShopPicByIds(ids);
    }

    /**
     * 删除积分商城图片信息信息
     * 
     * @param id 积分商城图片信息ID
     * @return 结果
     */
    @Override
    public int deleteIntegralShopPicById(Long id)
    {
        return integralShopPicMapper.deleteIntegralShopPicById(id);
    }
}
